summaryrefslogtreecommitdiff
path: root/tests/autotest-local.pl
diff options
context:
space:
mode:
Diffstat (limited to 'tests/autotest-local.pl')
-rw-r--r--tests/autotest-local.pl4
1 files changed, 2 insertions, 2 deletions
diff --git a/tests/autotest-local.pl b/tests/autotest-local.pl
index a419bb0..60f8b20 100644
--- a/tests/autotest-local.pl
+++ b/tests/autotest-local.pl
@@ -65,8 +65,8 @@ if ($fast)
print "### autotest begin " . scalar localtime() . "\n";
-# print SVN revision info
-print "### autotest revision $1\n" if (`svn info` =~ /Revision:\s+(\d+)/);
+# print Git revision info
+print "### autotest revision $1\n" if (`git rev-parse HEAD` =~ /(.+)/);
# get CPU info
$cpucount = &getcpucount();